==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/algorith/nmpich.f <==
      SUBROUTINE NMPICH(MODELE, NUMEDD, MATE  , CARELE, COMREF,
     &                  COMPOR, LISCHA, CNFEXT, PARMET, CARCRI,
     &                  MODEDE, NUMEDE, SOLVDE, PARCRI, POUGD ,
     &                  ITERAT, VALMOI, RESOCO, VALPLU, CNRESI,
     &                  CNDIRI, REAROT, FONACT, CONV,   INDRO ,    
     &                  PILOTE, DEPDEL, DEPPIL, DEPOLD, DINST,
     &                  SECMBR, ETA   , LICCVG, DDEPLA) 
     
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGORITH  DATE 06/04/2004   AUTEUR DURAND C.DURAND 
C ======================================================================
C COPYRIGHT (C) 1991 - 2003  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY  
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY  
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR     
C (AT YOUR OPTION) ANY LATER VERSION.                                   
C                                                                       
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT   
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF            
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU      
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                              
C                                                                       
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE     
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,         
C   1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.         
C ======================================================================
C TOLE CRP_21

      IMPLICIT NONE
      LOGICAL       REAROT, FONACT(4)
      INTEGER       ITERAT, LICCVG(2), INDRO, NBEFFE
      REAL*8        PARMET(*), CONV(*), INST(3), DINST, ETA
      REAL*8        PARCRI(*)
      CHARACTER*8   MODEDE
      CHARACTER*14  PILOTE
      CHARACTER*19  LISCHA, CNRESI, CNDIRI, CNFEXT, SOLVDE
      CHARACTER*24  MODELE, NUMEDD, MATE  , CARELE, COMREF, COMPOR
      CHARACTER*24  CARCRI, VALMOI, POUGD , DDEPLA, VALPLU, DEPDEL
      CHARACTER*24  RESOCO, SECMBR, DEPOLD, NUMEDE, DEPPIL(2)


C ----------------------------------------------------------------------
C
C                   CHOIX DE ETA 
C
C ----------------------------------------------------------------------
C
C IN       MODELE K24  MODELE
C IN       NUMEDD K24  NUME_DDL
C IN       MATE   K24  CHAMP MATERIAU
C IN       CARELE K24  CARACTERISTIQUES DES ELEMENTS DE STRUCTURE
C IN       COMREF K24  VARI_COM DE REFERENCE
C IN       COMPOR K24  COMPORTEMENT
C IN       LISCHA K19  L_CHARGES
C IN       CNFEXT K19  RESULTANTE DES EFFORTS EXTERIEURS
C IN       PARMET  R8  PARAMETRES DES METHODES DE RESOLUTION
C IN       CARCRI K24  PARAMETRES DES METHODES D'INTEGRATION LOCALES
C IN       MODEDE K8   MODELE NON LOCAL
C IN       NUMEDE K24  NUME_DDL NON LOCAL
C IN       SOLVDE K19  SOLVEUR NON LOCAL
C IN       PARCRI  R   CRITERES DE CONVERGENCE GLOBAUX
C IN       POUGD  K24  DONNES POUR POUTRES GRANDES DEFORMATIONS
C IN       ITERAT  I   NUMERO D'ITERATION DE NEWTON
C IN       VALMOI K24  ETAT EN T-
C IN       RESOCO K24  SD CONTACT
C IN/JXVAR VALPLU K24  ETAT EN T+ : SIGPLU ET VARPLU
C IN/JXVAR CNRESI K19  FINT+BT.LAMBDA
C IN/JXVAR CNDIRI K19  BT.LAMBDA
C IN       PILOTE K14  SD PILOTAGE
C IN       NBEFFE  I   NOMBRE DE VALEURS DE PILOTAGE ENTRANTES
C IN       DEPDEL K24  INCREMENT DE DEPLACEMENT CUMULE
C IN       DEPPIL K24  CORRECTION DE DEPLACEMENT DE L'ITERATION
C IN       DEPOLD K24  INCREMENT DE DEPLACEMENT PAS PRECEDENT (LONG_ARC)
C OUT      ETA     R8  PARAMETRE DE PILOTAGE
C OUT      LICCVG  I   CODE RETOUR 
C                       (1) PILOTAGE
C                       (2) LOI DE COMPORTEMENT (SI PILOTAGE RESIDU)
C OUT      DDEPLA K24  DIRECTION DE DESCENTE REACTUALISEE
C
C -------------- DEBUT DECLARATIONS NORMALISEES  JEVEUX ----------------
C
      CHARACTER*32       JEXNUM , JEXNOM , JEXATR
      INTEGER            ZI
      COMMON  / IVARJE / ZI(1)
      REAL*8             ZR
      COMMON  / RVARJE / ZR(1)
      COMPLEX*16         ZC
      COMMON  / CVARJE / ZC(1)
      LOGICAL            ZL
      COMMON  / LVARJE / ZL(1)
      CHARACTER*8        ZK8
      CHARACTER*16                ZK16
      CHARACTER*24                          ZK24
      CHARACTER*32                                    ZK32
      CHARACTER*80                                              ZK80
      COMMON  / KVARJE / ZK8(1) , ZK16(1) , ZK24(1) , ZK32(1) , ZK80(1)
C
C -------------- FIN  DECLARATIONS  NORMALISEES  JEVEUX ----------------

      INTEGER      NEQ,JDEPM,JDEPDE, JDEPP, JDDEPL,JDU0,JDU1
      REAL*8       PROETA(2), R8BID 
      CHARACTER*8  K8BID
      CHARACTER*24 DEPMOI, SIGMOI, VARMOI, COMMOI
      CHARACTER*24 DEPPLU, SIGPLU, VARPLU, COMPLU
      CHARACTER*24 K24BID, VARDEP, LAGDEP
      
      CALL JEMARQ()

C      CALCUL DE ETA_PILOTAGE
      IF (FONACT(2)) THEN
        CALL NMPILO(PILOTE, DINST , 1.D0  , 0.D0   , DEPPIL, 
     &              DEPDEL, DEPOLD, MODELE, MATE   , COMPOR, 
     &              VALMOI, 2     , NBEFFE, PROETA , LICCVG)
        IF (LICCVG(1).EQ.1) GOTO 9999
        CALL NMCETA(MODELE, NUMEDD, MATE  , CARELE, COMREF,
     &              COMPOR, LISCHA, CNFEXT, PARMET, CARCRI,
     &              MODEDE, NUMEDE, SOLVDE, PARCRI, POUGD ,
     &              ITERAT, VALMOI, RESOCO, VALPLU, CNRESI,
     &              CNDIRI, CONV,   INDRO , DEPOLD, .FALSE.,
     &              PILOTE, NBEFFE, PROETA, DEPDEL, DEPPIL, 
     &              REAROT, 0.D0,   1.D0, SECMBR, ETA   , LICCVG,
     &              R8BID) 

        CALL JEVEUO(DDEPLA(1:19) // '.VALE','E',JDDEPL)
        CALL JEVEUO (DEPPIL(1)(1:19)//'.VALE','E',JDU0)
        CALL JEVEUO (DEPPIL(2)(1:19)//'.VALE','E',JDU1)
        CALL JELIRA(DEPPIL(1)(1:19) // '.VALE', 'LONMAX', NEQ, K8BID)
        CALL R8COPY(NEQ, ZR(JDU0),1, ZR(JDDEPL),1)
        CALL R8AXPY(NEQ, ETA, ZR(JDU1),1, ZR(JDDEPL),1)
      
      ELSE
        ETA=0.D0
        CALL COPISD('CHAMP_GD','V',DEPPIL(1),DDEPLA)
      END IF
            
 9999 CONTINUE
      CALL JEDEMA()
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/algorith/nmpich.f <==
      SUBROUTINE NMPICH(MODELE, NUMEDD, MATE  , CARELE, COMREF,
     &                  COMPOR, LISCHA, CNFEXT, PARMET, CARCRI,
     &                  MODEDE, NUMEDE, SOLVDE, PARCRI, POUGD ,
     &                  ITERAT, VALMOI, RESOCO, VALPLU, CNRESI,
     &                  CNDIRI, REAROT, FONACT, CONV,   INDRO ,    
     &                  PILOTE, DEPDEL, DEPPIL, DEPOLD, DINST,
     &                  SECMBR, ETA   , LICCVG, DDEPLA) 
     
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGORITH  DATE 16/12/2004   AUTEUR VABHHTS J.PELLET 
C ======================================================================
C COPYRIGHT (C) 1991 - 2003  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY  
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY  
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR     
C (AT YOUR OPTION) ANY LATER VERSION.                                   
C                                                                       
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT   
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF            
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU      
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                              
C                                                                       
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE     
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,         
C   1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.         
C ======================================================================
C TOLE CRP_21

      IMPLICIT NONE
      LOGICAL       REAROT, FONACT(4)
      INTEGER       ITERAT, LICCVG(2), INDRO, NBEFFE
      REAL*8        PARMET(*), CONV(*), INST(3), DINST, ETA
      REAL*8        PARCRI(*)
      CHARACTER*8   MODEDE
      CHARACTER*14  PILOTE
      CHARACTER*19  LISCHA, CNRESI, CNDIRI, CNFEXT, SOLVDE
      CHARACTER*24  MODELE, NUMEDD, MATE  , CARELE, COMREF, COMPOR
      CHARACTER*24  CARCRI, VALMOI, POUGD , DDEPLA, VALPLU, DEPDEL
      CHARACTER*24  RESOCO, SECMBR, DEPOLD, NUMEDE, DEPPIL(2)


C ----------------------------------------------------------------------
C
C                   CHOIX DE ETA 
C
C ----------------------------------------------------------------------
C
C IN       MODELE K24  MODELE
C IN       NUMEDD K24  NUME_DDL
C IN       MATE   K24  CHAMP MATERIAU
C IN       CARELE K24  CARACTERISTIQUES DES ELEMENTS DE STRUCTURE
C IN       COMREF K24  VARI_COM DE REFERENCE
C IN       COMPOR K24  COMPORTEMENT
C IN       LISCHA K19  L_CHARGES
C IN       CNFEXT K19  RESULTANTE DES EFFORTS EXTERIEURS
C IN       PARMET  R8  PARAMETRES DES METHODES DE RESOLUTION
C IN       CARCRI K24  PARAMETRES DES METHODES D'INTEGRATION LOCALES
C IN       MODEDE K8   MODELE NON LOCAL
C IN       NUMEDE K24  NUME_DDL NON LOCAL
C IN       SOLVDE K19  SOLVEUR NON LOCAL
C IN       PARCRI  R   CRITERES DE CONVERGENCE GLOBAUX
C IN       POUGD  K24  DONNES POUR POUTRES GRANDES DEFORMATIONS
C IN       ITERAT  I   NUMERO D'ITERATION DE NEWTON
C IN       VALMOI K24  ETAT EN T-
C IN       RESOCO K24  SD CONTACT
C IN/JXVAR VALPLU K24  ETAT EN T+ : SIGPLU ET VARPLU
C IN/JXVAR CNRESI K19  FINT+BT.LAMBDA
C IN/JXVAR CNDIRI K19  BT.LAMBDA
C IN       PILOTE K14  SD PILOTAGE
C IN       NBEFFE  I   NOMBRE DE VALEURS DE PILOTAGE ENTRANTES
C IN       DEPDEL K24  INCREMENT DE DEPLACEMENT CUMULE
C IN       DEPPIL K24  CORRECTION DE DEPLACEMENT DE L'ITERATION
C IN       DEPOLD K24  INCREMENT DE DEPLACEMENT PAS PRECEDENT (LONG_ARC)
C OUT      ETA     R8  PARAMETRE DE PILOTAGE
C OUT      LICCVG  I   CODE RETOUR 
C                       (1) PILOTAGE
C                       (2) LOI DE COMPORTEMENT (SI PILOTAGE RESIDU)
C OUT      DDEPLA K24  DIRECTION DE DESCENTE REACTUALISEE
C
C -------------- DEBUT DECLARATIONS NORMALISEES  JEVEUX ----------------
C
      CHARACTER*32       JEXNUM , JEXNOM , JEXATR
      INTEGER            ZI
      COMMON  / IVARJE / ZI(1)
      REAL*8             ZR
      COMMON  / RVARJE / ZR(1)
      COMPLEX*16         ZC
      COMMON  / CVARJE / ZC(1)
      LOGICAL            ZL
      COMMON  / LVARJE / ZL(1)
      CHARACTER*8        ZK8
      CHARACTER*16                ZK16
      CHARACTER*24                          ZK24
      CHARACTER*32                                    ZK32
      CHARACTER*80                                              ZK80
      COMMON  / KVARJE / ZK8(1) , ZK16(1) , ZK24(1) , ZK32(1) , ZK80(1)
C
C -------------- FIN  DECLARATIONS  NORMALISEES  JEVEUX ----------------

      INTEGER      NEQ,JDEPM,JDEPDE, JDEPP, JDDEPL,JDU0,JDU1
      REAL*8       PROETA(2), R8BID 
      CHARACTER*8  K8BID
      CHARACTER*24 DEPMOI, SIGMOI, VARMOI, COMMOI
      CHARACTER*24 DEPPLU, SIGPLU, VARPLU, COMPLU
      CHARACTER*24 K24BID, VARDEP, LAGDEP
      
      CALL JEMARQ()

C      CALCUL DE ETA_PILOTAGE
      IF (FONACT(2)) THEN
        CALL NMPILO(PILOTE, DINST , 1.D0  , 0.D0   , DEPPIL, 
     &              DEPDEL, DEPOLD, MODELE, MATE   , COMPOR, 
     &              VALMOI, 2     , NBEFFE, PROETA , LICCVG)
        IF (LICCVG(1).EQ.1) GOTO 9999
        CALL NMCETA(MODELE, NUMEDD, MATE  , CARELE, COMREF,
     &              COMPOR, LISCHA, CNFEXT, PARMET, CARCRI,
     &              MODEDE, NUMEDE, SOLVDE, PARCRI, POUGD ,
     &              ITERAT, VALMOI, RESOCO, VALPLU, CNRESI,
     &              CNDIRI, CONV,   INDRO , DEPOLD, .FALSE.,
     &              PILOTE, NBEFFE, PROETA, DEPDEL, DEPPIL, 
     &              REAROT, 0.D0,   1.D0, SECMBR, ETA   , LICCVG,
     &              R8BID) 

        CALL JEVEUO(DDEPLA(1:19) // '.VALE','E',JDDEPL)
        CALL JEVEUO (DEPPIL(1)(1:19)//'.VALE','E',JDU0)
        CALL JEVEUO (DEPPIL(2)(1:19)//'.VALE','E',JDU1)
        CALL JELIRA(DEPPIL(1)(1:19) // '.VALE', 'LONMAX', NEQ, K8BID)
        CALL DCOPY(NEQ, ZR(JDU0),1, ZR(JDDEPL),1)
        CALL DAXPY(NEQ, ETA, ZR(JDU1),1, ZR(JDDEPL),1)
      
      ELSE
        ETA=0.D0
        CALL COPISD('CHAMP_GD','V',DEPPIL(1),DDEPLA)
      END IF
            
 9999 CONTINUE
      CALL JEDEMA()
      END
